#version 3.8;

// Include the macros implementing Narushin's egg formula
#include "egg.inc"

// Global settings
#include "rad_def.inc"
global_settings {
  radiosity {
    Rad_Settings(Radiosity_Normal,off,off)
    error_bound 2.0
    count 300
  }
  assumed_gamma 1.0
}
#default { finish { ambient 0 } }
background { color rgb 12/15 }

// Camera, orthographic to keep the shape undeformed and make it more
// readable
camera {
  orthographic
  right x up y * 3/4
  location -z look_at 0
}

// light source
light_source {
  <-.6,.5,-3> color rgb .4
  area_light x*.8, y*.8, 10 ,10 jitter orient
}

// Neutral grey background on which the eggs will be aligned
plane { z, 0 pigment { color rgb 12/15 } }

// Align several eggs in a 2D matrix on the plane with random parameters
#declare lengthEgg = 0.1;
#declare rndSeed = seed(1);
#declare scaleMin = 0.5;
#declare scaleMax = 1.0;
#declare iCol = 0;
#declare nbCol = 9;
#while (iCol < nbCol)
  #declare iRow = 0;
  #declare nbRow = 7;
  #while (iRow < nbRow)
    // Seed for the macro creating the egg shape, chosen arbitrarily
    #declare seedShape = iRow * nbCol + iCol + 700;
    // Seed for the texture creating the egg texture, chosen arbitrarily
    #declare seedTexture = seedShape;
    // Random radius for the egg, from equal to the egg length (spheric
    // egg) to half the length
    #declare radiusEgg = lengthEgg / 2 * (.5 + rand(rndSeed) * .5);
    // Egg object
    object {
      // Call the macro to create the egg
      EggRndShapeRndTexture(lengthEgg, radiusEgg, seedShape, seedTexture)
      // Scale the egg for nice looking variety
      #local scale_ = rand(rndSeed) * .5 + .5;
      scale scale_
      // Position the egg on the plane
      translate <iCol - (nbCol - 1) / 2, iRow - (nbRow - 1) / 2 - 0.5, 0> * lengthEgg
      translate radiusEgg * scale_ * -z
      // Add some perturbation to avoid perfect alignment
      translate <(rand(rndSeed)-.5)*.1,(rand(rndSeed)-.5)*.1,0.0> * lengthEgg
    }
    #declare iRow = iRow + 1;
  #end
  #declare iCol = iCol + 1;
#end
